summaryrefslogtreecommitdiffstats
path: root/juk/systemtray.h
diff options
context:
space:
mode:
Diffstat (limited to 'juk/systemtray.h')
-rw-r--r--juk/systemtray.h52
1 files changed, 26 insertions, 26 deletions
diff --git a/juk/systemtray.h b/juk/systemtray.h
index 8dd66a62..34e638c8 100644
--- a/juk/systemtray.h
+++ b/juk/systemtray.h
@@ -21,8 +21,8 @@
#include <ksystemtray.h>
#include <kpassivepopup.h>
-#include <qvaluevector.h>
-#include <qcolor.h>
+#include <tqvaluevector.h>
+#include <tqcolor.h>
class FlickerFreeLabel;
class QTimer;
@@ -39,7 +39,7 @@ class PassiveInfo : public KPassivePopup
{
Q_OBJECT
public:
- PassiveInfo(QWidget *parent = 0, const char *name = 0);
+ PassiveInfo(TQWidget *parent = 0, const char *name = 0);
public slots:
void setTimeout(int delay);
@@ -50,14 +50,14 @@ signals:
void timeExpired();
protected:
- virtual void enterEvent(QEvent *);
- virtual void leaveEvent(QEvent *);
+ virtual void enterEvent(TQEvent *);
+ virtual void leaveEvent(TQEvent *);
private slots:
void timerExpired();
private:
- QTimer *m_timer;
+ TQTimer *m_timer;
bool m_justDie;
};
@@ -66,7 +66,7 @@ class SystemTray : public KSystemTray
Q_OBJECT
public:
- SystemTray(QWidget *parent = 0, const char *name = 0);
+ SystemTray(TQWidget *parent = 0, const char *name = 0);
virtual ~SystemTray();
signals:
@@ -76,30 +76,30 @@ signals:
private:
static const int STEPS = 20; ///< Number of intermediate steps for fading.
- virtual void wheelEvent(QWheelEvent *e);
+ virtual void wheelEvent(TQWheelEvent *e);
void createPopup();
- void setToolTip(const QString &tip = QString::null, const QPixmap &cover = QPixmap());
- void mousePressEvent(QMouseEvent *e);
- QPixmap createPixmap(const QString &pixName);
+ void setToolTip(const TQString &tip = TQString::null, const TQPixmap &cover = TQPixmap());
+ void mousePressEvent(TQMouseEvent *e);
+ TQPixmap createPixmap(const TQString &pixName);
// Returns true if the popup will need to have its buttons on the left
// (because the JuK icon is on the left side of the screen.
bool buttonsToLeft() const;
- void createButtonBox(QWidget *parent);
+ void createButtonBox(TQWidget *parent);
- // Creates the widget layout for the popup, returning the QVBox that
+ // Creates the widget layout for the popup, returning the TQVBox that
// holds the text labels. Uses buttonsToLeft() to figure out which
// order to create them in. @p file is used to grab the cover.
- QVBox *createPopupLayout(QWidget *parent, const FileHandle &file);
+ TQVBox *createPopupLayout(TQWidget *parent, const FileHandle &file);
- void addSeparatorLine(QWidget *parent);
- void addCoverButton(QWidget *parent, const QPixmap &cover);
+ void addSeparatorLine(TQWidget *parent);
+ void addCoverButton(TQWidget *parent, const TQPixmap &cover);
// Interpolates from start color to end color. If @p step == 0, then
// m_startColor is returned, while @p step == @steps returns
// m_endColor.
- QColor interpolateColor(int step, int steps = STEPS);
+ TQColor interpolateColor(int step, int steps = STEPS);
private slots:
void slotPlay();
@@ -115,17 +115,17 @@ private slots:
void slotMouseInPopup(); ///< Forces the text back to its normal color.
private:
- QPixmap m_playPix;
- QPixmap m_pausePix;
- QPixmap m_currentPix;
- QPixmap m_backPix;
- QPixmap m_forwardPix;
- QPixmap m_appPix;
- QColor m_startColor, m_endColor;
+ TQPixmap m_playPix;
+ TQPixmap m_pausePix;
+ TQPixmap m_currentPix;
+ TQPixmap m_backPix;
+ TQPixmap m_forwardPix;
+ TQPixmap m_appPix;
+ TQColor m_startColor, m_endColor;
PassiveInfo *m_popup;
- QValueVector<FlickerFreeLabel *> m_labels;
- QTimer *m_fadeTimer;
+ TQValueVector<FlickerFreeLabel *> m_labels;
+ TQTimer *m_fadeTimer;
int m_step;
bool m_fade;
};